package com.ruoyi.abuwx.service;

import java.util.List;
import com.ruoyi.abuwx.domain.BannerInfo;
import com.ruoyi.abuwx.vo.BannerInfoVo;

/**
 * 轮播图管理Service接口
 * 
 * @author lujie
 * @date 2024-12-26
 */
public interface IBannerInfoService 
{
    /**
     * 查询轮播图管理
     * 
     * @param id 轮播图管理主键
     * @return 轮播图管理
     */
    public BannerInfo selectBannerInfoById(Long id);

    /**
     * 查询轮播图管理列表
     * 
     * @param bannerInfo 轮播图管理
     * @return 轮播图管理集合
     */
    public List<BannerInfo> selectBannerInfoList(BannerInfo bannerInfo);

    /**
     * 新增轮播图管理
     * 
     * @param bannerInfo 轮播图管理
     * @return 结果
     */
    public int insertBannerInfo(BannerInfo bannerInfo);

    /**
     * 修改轮播图管理
     * 
     * @param bannerInfo 轮播图管理
     * @return 结果
     */
    public int updateBannerInfo(BannerInfo bannerInfo);

    /**
     * 批量删除轮播图管理
     * 
     * @param ids 需要删除的轮播图管理主键集合
     * @return 结果
     */
    public int deleteBannerInfoByIds(Long[] ids);

    /**
     * 删除轮播图管理信息
     * 
     * @param id 轮播图管理主键
     * @return 结果
     */
    public int deleteBannerInfoById(Long id);

    List<BannerInfoVo> selectBannerInfoVoList(BannerInfo bannerInfo);
}
